pub enum ReaderRequest {
WatchAutoBrightness {
responder: ReaderWatchAutoBrightnessResponder,
},
WatchCurrentBrightness {
responder: ReaderWatchCurrentBrightnessResponder,
},
WatchAutoBrightnessAdjustment {
responder: ReaderWatchAutoBrightnessAdjustmentResponder,
},
GetMaxAbsoluteBrightness {
responder: ReaderGetMaxAbsoluteBrightnessResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ReaderControlHandle,
method_type: MethodType,
},
}Expand description
Reader provides read-only access to current brightness settings and state.
Variants
WatchAutoBrightness
Requests the current auto-brightness mode. This call implements the Hanging Get protocol.
Fields

responder: ReaderWatchAutoBrightnessResponderWatchCurrentBrightness
Gets the current brightness in the range 0.0 to 1.0. This result is valid for both manual and auto-brightness modes and is typically used to show the current brightness on a slider. This call implements the Hanging Get protocol.
Fields

responder: ReaderWatchCurrentBrightnessResponderWatchAutoBrightnessAdjustment
Gets the current auto brightness adjustment. This call implements the Hanging Get protocol.
Fields
GetMaxAbsoluteBrightness
Gets the maximum supported backlight brightness in nits, if known.
Fields

responder: ReaderGetMaxAbsoluteBrightnessResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: ReaderControlHandle
method_type: MethodTypeImplementations
Sourceimpl ReaderRequest
impl ReaderRequest
pub fn into_watch_auto_brightness( self, ) -> Option<ReaderWatchAutoBrightnessResponder>
pub fn into_watch_current_brightness( self, ) -> Option<ReaderWatchCurrentBrightnessResponder>
pub fn into_watch_auto_brightness_adjustment( self, ) -> Option<ReaderWatchAutoBrightnessAdjustmentResponder>
pub fn into_get_max_absolute_brightness( self, ) -> Option<ReaderGetMaxAbsoluteBrightnessResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL