pub struct ReaderProxy { /* private fields */ }Implementations
Sourceimpl ReaderProxy
impl ReaderProxy
Sourcepub fn take_event_stream(&self) -> ReaderEventStream
pub fn take_event_stream(&self) -> ReaderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch_auto_brightness(
&self,
) -> QueryResponseFut<bool, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch_auto_brightness( &self, ) -> QueryResponseFut<bool, DefaultFuchsiaResourceDialect> ⓘ
Requests the current auto-brightness mode. This call implements the Hanging Get protocol.
Sourcepub fn watch_current_brightness(
&self,
) -> QueryResponseFut<f32, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch_current_brightness( &self, ) -> QueryResponseFut<f32, DefaultFuchsiaResourceDialect> ⓘ
Gets the current brightness in the range 0.0 to 1.0. This result is valid for both manual and auto-brightness modes and is typically used to show the current brightness on a slider. This call implements the Hanging Get protocol.
Sourcepub fn watch_auto_brightness_adjustment(
&self,
) -> QueryResponseFut<f32, DefaultFuchsiaResourceDialect> ⓘ
pub fn watch_auto_brightness_adjustment( &self, ) -> QueryResponseFut<f32, DefaultFuchsiaResourceDialect> ⓘ
Gets the current auto brightness adjustment. This call implements the Hanging Get protocol.
Sourcepub fn get_max_absolute_brightness(
&self,
) -> QueryResponseFut<ReaderGetMaxAbsoluteBrightnessResult, DefaultFuchsiaResourceDialect> ⓘ
pub fn get_max_absolute_brightness( &self, ) -> QueryResponseFut<ReaderGetMaxAbsoluteBrightnessResult, DefaultFuchsiaResourceDialect> ⓘ
Gets the maximum supported backlight brightness in nits, if known.