pub struct ReaderSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ReaderSynchronousProxy
impl ReaderSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ReaderEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ReaderEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn watch_auto_brightness(
&self,
___deadline: MonotonicInstant,
) -> Result<bool, Error>
pub fn watch_auto_brightness( &self, ___deadline: MonotonicInstant, ) -> Result<bool, Error>
Requests the current auto-brightness mode. This call implements the Hanging Get protocol.
Sourcepub fn watch_current_brightness(
&self,
___deadline: MonotonicInstant,
) -> Result<f32, Error>
pub fn watch_current_brightness( &self, ___deadline: MonotonicInstant, ) -> Result<f32, Error>
Gets the current brightness in the range 0.0 to 1.0. This result is valid for both manual and auto-brightness modes and is typically used to show the current brightness on a slider. This call implements the Hanging Get protocol.
Sourcepub fn watch_auto_brightness_adjustment(
&self,
___deadline: MonotonicInstant,
) -> Result<f32, Error>
pub fn watch_auto_brightness_adjustment( &self, ___deadline: MonotonicInstant, ) -> Result<f32, Error>
Gets the current auto brightness adjustment. This call implements the Hanging Get protocol.
Sourcepub fn get_max_absolute_brightness(
&self,
___deadline: MonotonicInstant,
) -> Result<ReaderGetMaxAbsoluteBrightnessResult, Error>
pub fn get_max_absolute_brightness( &self, ___deadline: MonotonicInstant, ) -> Result<ReaderGetMaxAbsoluteBrightnessResult, Error>
Gets the maximum supported backlight brightness in nits, if known.