pub struct ReaderWatchAutoBrightnessAdjustmentResponse {
pub adjustment: f32,
}Fields
adjustment: f32Trait Implementations
Sourceimpl Clone for ReaderWatchAutoBrightnessAdjustmentResponse
impl Clone for ReaderWatchAutoBrightnessAdjustmentResponse
Sourcefn clone(&self) -> ReaderWatchAutoBrightnessAdjustmentResponse
fn clone(&self) -> ReaderWatchAutoBrightnessAdjustmentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReaderWatchAutoBrightnessAdjustmentResponse
Sourceimpl<D> Decode<ReaderWatchAutoBrightnessAdjustmentResponse, D> for ReaderWatchAutoBrightnessAdjustmentResponsewhere
D: ResourceDialect,
impl<D> Decode<ReaderWatchAutoBrightnessAdjustmentResponse, D> for ReaderWatchAutoBrightnessAdjustmentResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> ReaderWatchAutoBrightnessAdjustmentResponse
fn new_empty() -> ReaderWatchAutoBrightnessAdjustmentResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ReaderWatchAutoBrightnessAdjustmentResponse, D> for &ReaderWatchAutoBrightnessAdjustmentResponsewhere
D: ResourceDialect,
impl<D> Encode<ReaderWatchAutoBrightnessAdjustmentResponse, D> for &ReaderWatchAutoBrightnessAdjustmentResponsewhere
D: ResourceDialect,
Sourceimpl PartialOrd for ReaderWatchAutoBrightnessAdjustmentResponse
impl PartialOrd for ReaderWatchAutoBrightnessAdjustmentResponse
Sourcefn partial_cmp(
&self,
other: &ReaderWatchAutoBrightnessAdjustmentResponse,
) -> Option<Ordering>
fn partial_cmp( &self, other: &ReaderWatchAutoBrightnessAdjustmentResponse, ) -> Option<Ordering>
impl Persistable for ReaderWatchAutoBrightnessAdjustmentResponse
impl StructuralPartialEq for ReaderWatchAutoBrightnessAdjustmentResponse
Sourceimpl TypeMarker for ReaderWatchAutoBrightnessAdjustmentResponse
impl TypeMarker for ReaderWatchAutoBrightnessAdjustmentResponse
Sourcetype Owned = ReaderWatchAutoBrightnessAdjustmentResponse
type Owned = ReaderWatchAutoBrightnessAdjustmentResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ReaderWatchAutoBrightnessAdjustmentResponse
impl ValueTypeMarker for ReaderWatchAutoBrightnessAdjustmentResponse
Sourcetype Borrowed<'a> = &'a ReaderWatchAutoBrightnessAdjustmentResponse
type Borrowed<'a> = &'a ReaderWatchAutoBrightnessAdjustmentResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ReaderWatchAutoBrightnessAdjustmentResponse as TypeMarker>::Owned,
) -> <ReaderWatchAutoBrightnessAdjustmentResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ReaderWatchAutoBrightnessAdjustmentResponse as TypeMarker>::Owned, ) -> <ReaderWatchAutoBrightnessAdjustmentResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for ReaderWatchAutoBrightnessAdjustmentResponse
impl RefUnwindSafe for ReaderWatchAutoBrightnessAdjustmentResponse
impl Send for ReaderWatchAutoBrightnessAdjustmentResponse
impl Sync for ReaderWatchAutoBrightnessAdjustmentResponse
impl Unpin for ReaderWatchAutoBrightnessAdjustmentResponse
impl UnsafeUnpin for ReaderWatchAutoBrightnessAdjustmentResponse
impl UnwindSafe for ReaderWatchAutoBrightnessAdjustmentResponse