pub struct ReaderWatchAutoBrightnessResponse {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for ReaderWatchAutoBrightnessResponse
impl Clone for ReaderWatchAutoBrightnessResponse
Sourcefn clone(&self) -> ReaderWatchAutoBrightnessResponse
fn clone(&self) -> ReaderWatchAutoBrightnessResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReaderWatchAutoBrightnessResponse
Sourceimpl<D> Decode<ReaderWatchAutoBrightnessResponse, D> for ReaderWatchAutoBrightnessResponsewhere
D: ResourceDialect,
impl<D> Decode<ReaderWatchAutoBrightnessResponse, D> for ReaderWatchAutoBrightnessResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> ReaderWatchAutoBrightnessResponse
fn new_empty() -> ReaderWatchAutoBrightnessResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ReaderWatchAutoBrightnessResponse, D> for &ReaderWatchAutoBrightnessResponsewhere
D: ResourceDialect,
impl<D> Encode<ReaderWatchAutoBrightnessResponse, D> for &ReaderWatchAutoBrightnessResponsewhere
D: ResourceDialect,
impl Eq for ReaderWatchAutoBrightnessResponse
Sourceimpl Ord for ReaderWatchAutoBrightnessResponse
impl Ord for ReaderWatchAutoBrightnessResponse
Sourcefn cmp(&self, other: &ReaderWatchAutoBrightnessResponse) -> Ordering
fn cmp(&self, other: &ReaderWatchAutoBrightnessResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for ReaderWatchAutoBrightnessResponse
impl PartialOrd for ReaderWatchAutoBrightnessResponse
impl Persistable for ReaderWatchAutoBrightnessResponse
impl StructuralPartialEq for ReaderWatchAutoBrightnessResponse
Sourceimpl TypeMarker for ReaderWatchAutoBrightnessResponse
impl TypeMarker for ReaderWatchAutoBrightnessResponse
Sourcetype Owned = ReaderWatchAutoBrightnessResponse
type Owned = ReaderWatchAutoBrightnessResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ReaderWatchAutoBrightnessResponse
impl ValueTypeMarker for ReaderWatchAutoBrightnessResponse
Sourcetype Borrowed<'a> = &'a ReaderWatchAutoBrightnessResponse
type Borrowed<'a> = &'a ReaderWatchAutoBrightnessResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ReaderWatchAutoBrightnessResponse as TypeMarker>::Owned,
) -> <ReaderWatchAutoBrightnessResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ReaderWatchAutoBrightnessResponse as TypeMarker>::Owned, ) -> <ReaderWatchAutoBrightnessResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for ReaderWatchAutoBrightnessResponse
impl RefUnwindSafe for ReaderWatchAutoBrightnessResponse
impl Send for ReaderWatchAutoBrightnessResponse
impl Sync for ReaderWatchAutoBrightnessResponse
impl Unpin for ReaderWatchAutoBrightnessResponse
impl UnsafeUnpin for ReaderWatchAutoBrightnessResponse
impl UnwindSafe for ReaderWatchAutoBrightnessResponse