pub struct ReaderWatchCurrentBrightnessResponse {
pub value: f32,
}Fields
value: f32Trait Implementations
Sourceimpl Clone for ReaderWatchCurrentBrightnessResponse
impl Clone for ReaderWatchCurrentBrightnessResponse
Sourcefn clone(&self) -> ReaderWatchCurrentBrightnessResponse
fn clone(&self) -> ReaderWatchCurrentBrightnessResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ReaderWatchCurrentBrightnessResponse
Sourceimpl<D> Decode<ReaderWatchCurrentBrightnessResponse, D> for ReaderWatchCurrentBrightnessResponsewhere
D: ResourceDialect,
impl<D> Decode<ReaderWatchCurrentBrightnessResponse, D> for ReaderWatchCurrentBrightnessResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> ReaderWatchCurrentBrightnessResponse
fn new_empty() -> ReaderWatchCurrentBrightnessResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ReaderWatchCurrentBrightnessResponse, D> for &ReaderWatchCurrentBrightnessResponsewhere
D: ResourceDialect,
impl<D> Encode<ReaderWatchCurrentBrightnessResponse, D> for &ReaderWatchCurrentBrightnessResponsewhere
D: ResourceDialect,
Sourceimpl PartialOrd for ReaderWatchCurrentBrightnessResponse
impl PartialOrd for ReaderWatchCurrentBrightnessResponse
impl Persistable for ReaderWatchCurrentBrightnessResponse
impl StructuralPartialEq for ReaderWatchCurrentBrightnessResponse
Sourceimpl TypeMarker for ReaderWatchCurrentBrightnessResponse
impl TypeMarker for ReaderWatchCurrentBrightnessResponse
Sourcetype Owned = ReaderWatchCurrentBrightnessResponse
type Owned = ReaderWatchCurrentBrightnessResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ReaderWatchCurrentBrightnessResponse
impl ValueTypeMarker for ReaderWatchCurrentBrightnessResponse
Sourcetype Borrowed<'a> = &'a ReaderWatchCurrentBrightnessResponse
type Borrowed<'a> = &'a ReaderWatchCurrentBrightnessResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ReaderWatchCurrentBrightnessResponse as TypeMarker>::Owned,
) -> <ReaderWatchCurrentBrightnessResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ReaderWatchCurrentBrightnessResponse as TypeMarker>::Owned, ) -> <ReaderWatchCurrentBrightnessResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for ReaderWatchCurrentBrightnessResponse
impl RefUnwindSafe for ReaderWatchCurrentBrightnessResponse
impl Send for ReaderWatchCurrentBrightnessResponse
impl Sync for ReaderWatchCurrentBrightnessResponse
impl Unpin for ReaderWatchCurrentBrightnessResponse
impl UnsafeUnpin for ReaderWatchCurrentBrightnessResponse
impl UnwindSafe for ReaderWatchCurrentBrightnessResponse